<?php
/**
 * Zend Framework (http://framework.zend.com/)
 *
 * @link      http://github.com/zendframework/zf2 for the canonical source repository
 * @copyright Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
 * @license   http://framework.zend.com/license/new-bsd New BSD License
 * @package   Zend_Db
 */

namespace Zend\Db\TableGateway\Feature;

use Zend\EventManager\EventManagerInterface,
    Zend\Db\TableGateway\Exception,
    Zend\Db\Sql\Select,
    Zend\Db\Sql\Insert,
    Zend\Db\Sql\Update,
    Zend\Db\Sql\Delete,
    Zend\Db\Adapter\Driver\StatementInterface,
    Zend\Db\Adapter\Driver\ResultInterface,
    Zend\Db\ResultSet\ResultSet;

/**
 * @category   Zend
 * @package    Zend_Db
 * @subpackage TableGateway
 */
class EventFeature extends AbstractFeature
{

    /**
     * @var EventManagerInterface
     */
    protected $eventManager = null;

    /**
     * @var null
     */
    protected $event = null;

    /**
     * @param EventManagerInterface $eventManager
     * @param EventFeature\TableGatewayEvent $tableGatewayEvent
     */
    public function __construct(EventManagerInterface $eventManager, EventFeature\TableGatewayEvent $tableGatewayEvent)
    {
        $this->eventManager = $eventManager;
        $this->event = ($tableGatewayEvent) ?: new EventFeature\TableGatewayEvent();
    }

    public function preInitialize()
    {
        $this->event->setTarget($this->tableGateway);
        $this->event->setName(__FUNCTION__);
        $this->eventManager->trigger($this->event);
    }

    public function postInitialize()
    {
        $this->event->setTarget($this->tableGateway);
        $this->event->setName(__FUNCTION__);
        $this->eventManager->trigger($this->event);
    }

    public function preSelect(Select $select)
    {
        $this->event->setTarget($this->tableGateway);
        $this->event->setName(__FUNCTION__);
        $this->event->setParams(array('select' => $select));
        $this->eventManager->trigger($this->event);
    }

    public function postSelect(StatementInterface $statement, ResultInterface $result, ResultSet $resultSet)
    {
        $this->event->setTarget($this->tableGateway);
        $this->event->setName(__FUNCTION__);
        $this->event->setParams(array(
            'statement' => $statement,
            'result' => $result,
            'result_set' => $resultSet
        ));
        $this->eventManager->trigger($this->event);
    }

    public function preInsert(Insert $insert)
    {
        $this->event->setTarget($this->tableGateway);
        $this->event->setName(__FUNCTION__);
        $this->event->setParams(array('insert' => $insert));
        $this->eventManager->trigger($this->event);
    }

    public function postInsert(StatementInterface $statement, ResultInterface $result)
    {
        $this->event->setTarget($this->tableGateway);
        $this->event->setName(__FUNCTION__);
        $this->event->setParams(array(
            'statement' => $statement,
            'result' => $result,
        ));
        $this->eventManager->trigger($this->event);
    }

    public function preUpdate(Update $update)
    {
        $this->event->setTarget($this->tableGateway);
        $this->event->setName(__FUNCTION__);
        $this->event->setParams(array('update' => $update));
        $this->eventManager->trigger($this->event);
    }

    public function postUpdate(StatementInterface $statement, ResultInterface $result)
    {
        $this->event->setTarget($this->tableGateway);
        $this->event->setName(__FUNCTION__);
        $this->event->setParams(array(
            'statement' => $statement,
            'result' => $result,
        ));
        $this->eventManager->trigger($this->event);
    }

    public function preDelete(Delete $delete)
    {
        $this->event->setTarget($this->tableGateway);
        $this->event->setName(__FUNCTION__);
        $this->event->setParams(array('delete' => $delete));
        $this->eventManager->trigger($this->event);
    }

    public function postDelete(StatementInterface $statement, ResultInterface $result)
    {
        $this->event->setTarget($this->tableGateway);
        $this->event->setName(__FUNCTION__);
        $this->event->setParams(array(
            'statement' => $statement,
            'result' => $result,
        ));
        $this->eventManager->trigger($this->event);
    }

}
